from setuptools import setup, find_packages

setup(
    name = 'sterra',
    version = '0.0.0',
    description = 'Simply reserving this name for sterraxcyl',
    author = 'novitae',
    url = 'https://github.com/novitae',
)